<?php

namespace WSCOMUN\REGDEPARTAMENTAL;

use \ArrayObject;
use \SoapVar;
use \Exception;

const unbounded = 'unbounded';



/**
 *
 * @author pbelenguer
 * @author pascual_dav@externos.gva.es
 *
 */
class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	*/
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
//var_dump($childData);
//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
//				var_dump($vChildData);die;
			}
		}

//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		var_dump($parentTag);
		var_dump($vData);
		var_dump($fieldName);
		var_dump($type);
		var_dump($namespace);
		var_dump($minOccurs);
		var_dump($maxOccurs);

		die("FAIL!!!");
		*/

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}












class ErrorInfoType extends SoapObject {
	// name="codigoError" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoError = null;
	private $_hasCodigoError = false;
	public function setCodigoError($value) {
		$this->_codigoError = $value;
		$this->_hasCodigoError = ($value !== null);
	}
	public function hasCodigoError() {
		return $this->_hasCodigoError;
	}
	public function getCodigoError() {
		return $this->_codigoError;
	}

	// name="descripcionError" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_descripcionError = null;
	private $_hasDescripcionError = false;
	public function setDescripcionError($value) {
		$this->_descripcionError = $value;
		$this->_hasDescripcionError = ($value !== null);
	}
	public function hasDescripcionError() {
		return $this->_hasDescripcionError;
	}
	public function getDescripcionError() {
		return $this->_descripcionError;
	}


	static public function fromSoap($vData) {
		$newItem = new ErrorInfoType();
		if (!isset($vData['codigoError'])) {
			throw new Exception('El parametro codigoError es obligatorio');
		}
		if (isset($vData['codigoError'])) {
			$newItem->setCodigoError($vData['codigoError']);
		}
		if (!isset($vData['descripcionError'])) {
			throw new Exception('El parametro descripcionError es obligatorio');
		}
		if (isset($vData['descripcionError'])) {
			$newItem->setDescripcionError($vData['descripcionError']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoError, 'codigoError', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_descripcionError, 'descripcionError', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DocumentoIdentificativoType extends SoapObject {
	// name="tipoDocumentoIdentificativo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_tipoDocumentoIdentificativo = null;
	private $_hasTipoDocumentoIdentificativo = false;
	public function setTipoDocumentoIdentificativo($value) {
		$this->_tipoDocumentoIdentificativo = $value;
		$this->_hasTipoDocumentoIdentificativo = ($value !== null);
	}
	public function hasTipoDocumentoIdentificativo() {
		return $this->_hasTipoDocumentoIdentificativo;
	}
	public function getTipoDocumentoIdentificativo() {
		return $this->_tipoDocumentoIdentificativo;
	}

	// name="numeroDocumentoIdentificativo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_numeroDocumentoIdentificativo = null;
	private $_hasNumeroDocumentoIdentificativo = false;
	public function setNumeroDocumentoIdentificativo($value) {
		$this->_numeroDocumentoIdentificativo = $value;
		$this->_hasNumeroDocumentoIdentificativo = ($value !== null);
	}
	public function hasNumeroDocumentoIdentificativo() {
		return $this->_hasNumeroDocumentoIdentificativo;
	}
	public function getNumeroDocumentoIdentificativo() {
		return $this->_numeroDocumentoIdentificativo;
	}


	static public function fromSoap($vData) {
		$newItem = new DocumentoIdentificativoType();
		if (!isset($vData['tipoDocumentoIdentificativo'])) {
			throw new Exception('El parametro tipoDocumentoIdentificativo es obligatorio');
		}
		if (isset($vData['tipoDocumentoIdentificativo'])) {
			$newItem->setTipoDocumentoIdentificativo($vData['tipoDocumentoIdentificativo']);
		}
		if (!isset($vData['numeroDocumentoIdentificativo'])) {
			throw new Exception('El parametro numeroDocumentoIdentificativo es obligatorio');
		}
		if (isset($vData['numeroDocumentoIdentificativo'])) {
			$newItem->setNumeroDocumentoIdentificativo($vData['numeroDocumentoIdentificativo']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_tipoDocumentoIdentificativo, 'tipoDocumentoIdentificativo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_numeroDocumentoIdentificativo, 'numeroDocumentoIdentificativo', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class RegistrosCreadosType extends SoapObject {
	// name="registroCreado" type="tns:RegistroCreadoType"[COMPLEXTYPE] minOccurs="1" maxOccurs="unbounded" nillable="false"
	private $_registroCreado = array();
	private $_hasRegistroCreado = false;
	public function replaceArrayRegistroCreado($value) {
		$this->_registroCreado = $value;
		$this->_hasRegistroCreado = (isset($this->_registroCreado) && !empty($this->_registroCreado));
	}
	public function retrieveArrayRegistroCreado() {
		return $this->_registroCreado;
	}
	public function addRegistroCreado($value) {
		array_push($this->_registroCreado, $value);
		$this->_hasRegistroCreado = (isset($this->_registroCreado) && !empty($this->_registroCreado));
	}
	public function hasRegistroCreado() {
		return $this->_hasRegistroCreado;
	}
	public function getRegistroCreado($index) {
		return $this->_registroCreado[$index];
	}
	public function countRegistroCreado() {
		return count($this->_registroCreado);
	}


	static public function fromSoap($vData) {
		$newItem = new RegistrosCreadosType();
		if (!isset($vData['registroCreado'])) {
			throw new Exception('El parametro registroCreado es obligatorio');
		}
		if (isset($vData['registroCreado']) && !empty($vData['registroCreado'])) {
			if (SoapObject::is_assoc($vData['registroCreado'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = RegistroCreadoType::fromSoap($vData['registroCreado']);
				$newItem->addRegistroCreado($newClass);
			} else {
				foreach ($vData['registroCreado'] as $oVar) {
					$newClass = RegistroCreadoType::fromSoap($oVar);
					$newItem->addRegistroCreado($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_registroCreado, 'registroCreado', SOAP_ENC_OBJECT, $namespace, 1, unbounded);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class RegistroCreadoType extends SoapObject {
	// name="resultado" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_resultado = null;
	private $_hasResultado = false;
	public function setResultado($value) {
		$this->_resultado = $value;
		$this->_hasResultado = ($value !== null);
	}
	public function hasResultado() {
		return $this->_hasResultado;
	}
	public function getResultado() {
		return $this->_resultado;
	}

	// name="destino" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_destino = null;
	private $_hasDestino = false;
	public function setDestino($value) {
		$this->_destino = $value;
		$this->_hasDestino = ($value !== null);
	}
	public function hasDestino() {
		return $this->_hasDestino;
	}
	public function getDestino() {
		return $this->_destino;
	}

	// name="codigoRegistro" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoRegistro = null;
	private $_hasCodigoRegistro = false;
	public function setCodigoRegistro($value) {
		$this->_codigoRegistro = $value;
		$this->_hasCodigoRegistro = ($value !== null);
	}
	public function hasCodigoRegistro() {
		return $this->_hasCodigoRegistro;
	}
	public function getCodigoRegistro() {
		return $this->_codigoRegistro;
	}

	// name="fechaRegistro" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fechaRegistro = null;
	private $_hasFechaRegistro = false;
	public function setFechaRegistro($value) {
		$this->_fechaRegistro = $value;
		$this->_hasFechaRegistro = ($value !== null);
	}
	public function hasFechaRegistro() {
		return $this->_hasFechaRegistro;
	}
	public function getFechaRegistro() {
		return $this->_fechaRegistro;
	}

	// name="error" type="tns:ErrorInfoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_error = null;
	private $_hasError = false;
	public function setError($value) {
		$this->_error = $value;
		$this->_hasError = ($value !== null);
	}
	public function hasError() {
		return $this->_hasError;
	}
	public function getError() {
		return $this->_error;
	}


	static public function fromSoap($vData) {
		$newItem = new RegistroCreadoType();
		if (!isset($vData['resultado'])) {
			throw new Exception('El parametro resultado es obligatorio');
		}
		if (isset($vData['resultado'])) {
			$newItem->setResultado($vData['resultado']);
		}
		if (isset($vData['destino'])) {
			$newItem->setDestino($vData['destino']);
		}
		if (isset($vData['codigoRegistro'])) {
			$newItem->setCodigoRegistro($vData['codigoRegistro']);
		}
		if (isset($vData['fechaRegistro'])) {
			$newItem->setFechaRegistro($vData['fechaRegistro']);
		}
		if (isset($vData['error'])) {
			$newClass = ErrorInfoType::fromSoap($vData['error']);
			$newItem->setError($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_resultado, 'resultado', 102, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_destino, 'destino', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoRegistro, 'codigoRegistro', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fechaRegistro, 'fechaRegistro', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_error, 'error', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class RegistroDepartamentalCodigoType extends SoapObject {
	// name="codigoRegistro" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoRegistro = null;
	private $_hasCodigoRegistro = false;
	public function setCodigoRegistro($value) {
		$this->_codigoRegistro = $value;
		$this->_hasCodigoRegistro = ($value !== null);
	}
	public function hasCodigoRegistro() {
		return $this->_hasCodigoRegistro;
	}
	public function getCodigoRegistro() {
		return $this->_codigoRegistro;
	}

	// name="fechaRegistro" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_fechaRegistro = null;
	private $_hasFechaRegistro = false;
	public function setFechaRegistro($value) {
		$this->_fechaRegistro = $value;
		$this->_hasFechaRegistro = ($value !== null);
	}
	public function hasFechaRegistro() {
		return $this->_hasFechaRegistro;
	}
	public function getFechaRegistro() {
		return $this->_fechaRegistro;
	}


	static public function fromSoap($vData) {
		$newItem = new RegistroDepartamentalCodigoType();
		if (!isset($vData['codigoRegistro'])) {
			throw new Exception('El parametro codigoRegistro es obligatorio');
		}
		if (isset($vData['codigoRegistro'])) {
			$newItem->setCodigoRegistro($vData['codigoRegistro']);
		}
		if (!isset($vData['fechaRegistro'])) {
			throw new Exception('El parametro fechaRegistro es obligatorio');
		}
		if (isset($vData['fechaRegistro'])) {
			$newItem->setFechaRegistro($vData['fechaRegistro']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoRegistro, 'codigoRegistro', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fechaRegistro, 'fechaRegistro', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class HistoricoType extends SoapObject {
	// name="registros" type="tns:RegistroDescendenteType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_registros = null;
	private $_hasRegistros = false;
	public function setRegistros($value) {
		$this->_registros = $value;
		$this->_hasRegistros = ($value !== null);
	}
	public function hasRegistros() {
		return $this->_hasRegistros;
	}
	public function getRegistros() {
		return $this->_registros;
	}


	static public function fromSoap($vData) {
		$newItem = new HistoricoType();
		if (!isset($vData['registros'])) {
			throw new Exception('El parametro registros es obligatorio');
		}
		if (isset($vData['registros'])) {
			$newClass = RegistroDescendenteType::fromSoap($vData['registros']);
			$newItem->setRegistros($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_registros, 'registros', SOAP_ENC_OBJECT, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class RegistroDescendenteType extends SoapObject {
	// name="codigoRegistro" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoRegistro = null;
	private $_hasCodigoRegistro = false;
	public function setCodigoRegistro($value) {
		$this->_codigoRegistro = $value;
		$this->_hasCodigoRegistro = ($value !== null);
	}
	public function hasCodigoRegistro() {
		return $this->_hasCodigoRegistro;
	}
	public function getCodigoRegistro() {
		return $this->_codigoRegistro;
	}

	// name="fechaRegistro" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_fechaRegistro = null;
	private $_hasFechaRegistro = false;
	public function setFechaRegistro($value) {
		$this->_fechaRegistro = $value;
		$this->_hasFechaRegistro = ($value !== null);
	}
	public function hasFechaRegistro() {
		return $this->_hasFechaRegistro;
	}
	public function getFechaRegistro() {
		return $this->_fechaRegistro;
	}

	// name="tipoRegistro" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_tipoRegistro = null;
	private $_hasTipoRegistro = false;
	public function setTipoRegistro($value) {
		$this->_tipoRegistro = $value;
		$this->_hasTipoRegistro = ($value !== null);
	}
	public function hasTipoRegistro() {
		return $this->_hasTipoRegistro;
	}
	public function getTipoRegistro() {
		return $this->_tipoRegistro;
	}

	// name="registroDescendente" type="tns:RegistroDescendenteType"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_registroDescendente = array();
	private $_hasRegistroDescendente = false;
	public function replaceArrayRegistroDescendente($value) {
		$this->_registroDescendente = $value;
		$this->_hasRegistroDescendente = (isset($this->_registroDescendente) && !empty($this->_registroDescendente));
	}
	public function retrieveArrayRegistroDescendente() {
		return $this->_registroDescendente;
	}
	public function addRegistroDescendente($value) {
		array_push($this->_registroDescendente, $value);
		$this->_hasRegistroDescendente = (isset($this->_registroDescendente) && !empty($this->_registroDescendente));
	}
	public function hasRegistroDescendente() {
		return $this->_hasRegistroDescendente;
	}
	public function getRegistroDescendente($index) {
		return $this->_registroDescendente[$index];
	}
	public function countRegistroDescendente() {
		return count($this->_registroDescendente);
	}


	static public function fromSoap($vData) {
		$newItem = new RegistroDescendenteType();
		if (!isset($vData['codigoRegistro'])) {
			throw new Exception('El parametro codigoRegistro es obligatorio');
		}
		if (isset($vData['codigoRegistro'])) {
			$newItem->setCodigoRegistro($vData['codigoRegistro']);
		}
		if (!isset($vData['fechaRegistro'])) {
			throw new Exception('El parametro fechaRegistro es obligatorio');
		}
		if (isset($vData['fechaRegistro'])) {
			$newItem->setFechaRegistro($vData['fechaRegistro']);
		}
		if (!isset($vData['tipoRegistro'])) {
			throw new Exception('El parametro tipoRegistro es obligatorio');
		}
		if (isset($vData['tipoRegistro'])) {
			$newItem->setTipoRegistro($vData['tipoRegistro']);
		}
		if (isset($vData['registroDescendente']) && !empty($vData['registroDescendente'])) {
			if (SoapObject::is_assoc($vData['registroDescendente'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = RegistroDescendenteType::fromSoap($vData['registroDescendente']);
				$newItem->addRegistroDescendente($newClass);
			} else {
				foreach ($vData['registroDescendente'] as $oVar) {
					$newClass = RegistroDescendenteType::fromSoap($oVar);
					$newItem->addRegistroDescendente($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoRegistro, 'codigoRegistro', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fechaRegistro, 'fechaRegistro', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_tipoRegistro, 'tipoRegistro', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_registroDescendente, 'registroDescendente', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosDomicilioType extends SoapObject {
	// name="direccion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_direccion = null;
	private $_hasDireccion = false;
	public function setDireccion($value) {
		$this->_direccion = $value;
		$this->_hasDireccion = ($value !== null);
	}
	public function hasDireccion() {
		return $this->_hasDireccion;
	}
	public function getDireccion() {
		return $this->_direccion;
	}

	// name="codigoPostal" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoPostal = null;
	private $_hasCodigoPostal = false;
	public function setCodigoPostal($value) {
		$this->_codigoPostal = $value;
		$this->_hasCodigoPostal = ($value !== null);
	}
	public function hasCodigoPostal() {
		return $this->_hasCodigoPostal;
	}
	public function getCodigoPostal() {
		return $this->_codigoPostal;
	}

	// name="codigoProvincia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoProvincia = null;
	private $_hasCodigoProvincia = false;
	public function setCodigoProvincia($value) {
		$this->_codigoProvincia = $value;
		$this->_hasCodigoProvincia = ($value !== null);
	}
	public function hasCodigoProvincia() {
		return $this->_hasCodigoProvincia;
	}
	public function getCodigoProvincia() {
		return $this->_codigoProvincia;
	}

	// name="codigoMunicipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoMunicipio = null;
	private $_hasCodigoMunicipio = false;
	public function setCodigoMunicipio($value) {
		$this->_codigoMunicipio = $value;
		$this->_hasCodigoMunicipio = ($value !== null);
	}
	public function hasCodigoMunicipio() {
		return $this->_hasCodigoMunicipio;
	}
	public function getCodigoMunicipio() {
		return $this->_codigoMunicipio;
	}

	// name="descripcionMunicipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_descripcionMunicipio = null;
	private $_hasDescripcionMunicipio = false;
	public function setDescripcionMunicipio($value) {
		$this->_descripcionMunicipio = $value;
		$this->_hasDescripcionMunicipio = ($value !== null);
	}
	public function hasDescripcionMunicipio() {
		return $this->_hasDescripcionMunicipio;
	}
	public function getDescripcionMunicipio() {
		return $this->_descripcionMunicipio;
	}

	// name="codigoPoblacion" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoPoblacion = null;
	private $_hasCodigoPoblacion = false;
	public function setCodigoPoblacion($value) {
		$this->_codigoPoblacion = $value;
		$this->_hasCodigoPoblacion = ($value !== null);
	}
	public function hasCodigoPoblacion() {
		return $this->_hasCodigoPoblacion;
	}
	public function getCodigoPoblacion() {
		return $this->_codigoPoblacion;
	}

	// name="pais" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_pais = null;
	private $_hasPais = false;
	public function setPais($value) {
		$this->_pais = $value;
		$this->_hasPais = ($value !== null);
	}
	public function hasPais() {
		return $this->_hasPais;
	}
	public function getPais() {
		return $this->_pais;
	}

	// name="telefono" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_telefono = null;
	private $_hasTelefono = false;
	public function setTelefono($value) {
		$this->_telefono = $value;
		$this->_hasTelefono = ($value !== null);
	}
	public function hasTelefono() {
		return $this->_hasTelefono;
	}
	public function getTelefono() {
		return $this->_telefono;
	}

	// name="fax" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fax = null;
	private $_hasFax = false;
	public function setFax($value) {
		$this->_fax = $value;
		$this->_hasFax = ($value !== null);
	}
	public function hasFax() {
		return $this->_hasFax;
	}
	public function getFax() {
		return $this->_fax;
	}


	static public function fromSoap($vData) {
		$newItem = new DatosDomicilioType();
		if (isset($vData['direccion'])) {
			$newItem->setDireccion($vData['direccion']);
		}
		if (isset($vData['codigoPostal'])) {
			$newItem->setCodigoPostal($vData['codigoPostal']);
		}
		if (isset($vData['codigoProvincia'])) {
			$newItem->setCodigoProvincia($vData['codigoProvincia']);
		}
		if (isset($vData['codigoMunicipio'])) {
			$newItem->setCodigoMunicipio($vData['codigoMunicipio']);
		}
		if (isset($vData['descripcionMunicipio'])) {
			$newItem->setDescripcionMunicipio($vData['descripcionMunicipio']);
		}
		if (isset($vData['codigoPoblacion'])) {
			$newItem->setCodigoPoblacion($vData['codigoPoblacion']);
		}
		if (isset($vData['pais'])) {
			$newItem->setPais($vData['pais']);
		}
		if (isset($vData['telefono'])) {
			$newItem->setTelefono($vData['telefono']);
		}
		if (isset($vData['fax'])) {
			$newItem->setFax($vData['fax']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_direccion, 'direccion', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoPostal, 'codigoPostal', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoProvincia, 'codigoProvincia', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoMunicipio, 'codigoMunicipio', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_descripcionMunicipio, 'descripcionMunicipio', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoPoblacion, 'codigoPoblacion', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_pais, 'pais', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_telefono, 'telefono', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fax, 'fax', 101, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosIdentificativosType extends SoapObject {
	// name="documentoIdentificativo" type="tns:DocumentoIdentificativoType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_documentoIdentificativo = null;
	private $_hasDocumentoIdentificativo = false;
	public function setDocumentoIdentificativo($value) {
		$this->_documentoIdentificativo = $value;
		$this->_hasDocumentoIdentificativo = ($value !== null);
	}
	public function hasDocumentoIdentificativo() {
		return $this->_hasDocumentoIdentificativo;
	}
	public function getDocumentoIdentificativo() {
		return $this->_documentoIdentificativo;
	}

	// name="nombreApellidos" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_nombreApellidos = null;
	private $_hasNombreApellidos = false;
	public function setNombreApellidos($value) {
		$this->_nombreApellidos = $value;
		$this->_hasNombreApellidos = ($value !== null);
	}
	public function hasNombreApellidos() {
		return $this->_hasNombreApellidos;
	}
	public function getNombreApellidos() {
		return $this->_nombreApellidos;
	}

	// name="nombre" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}

	// name="apellido1" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_apellido1 = null;
	private $_hasApellido1 = false;
	public function setApellido1($value) {
		$this->_apellido1 = $value;
		$this->_hasApellido1 = ($value !== null);
	}
	public function hasApellido1() {
		return $this->_hasApellido1;
	}
	public function getApellido1() {
		return $this->_apellido1;
	}

	// name="apellido2" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_apellido2 = null;
	private $_hasApellido2 = false;
	public function setApellido2($value) {
		$this->_apellido2 = $value;
		$this->_hasApellido2 = ($value !== null);
	}
	public function hasApellido2() {
		return $this->_hasApellido2;
	}
	public function getApellido2() {
		return $this->_apellido2;
	}

	// name="domicilio" type="tns:DatosDomicilioType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_domicilio = null;
	private $_hasDomicilio = false;
	public function setDomicilio($value) {
		$this->_domicilio = $value;
		$this->_hasDomicilio = ($value !== null);
	}
	public function hasDomicilio() {
		return $this->_hasDomicilio;
	}
	public function getDomicilio() {
		return $this->_domicilio;
	}


	static public function fromSoap($vData) {
		$newItem = new DatosIdentificativosType();
		if (!isset($vData['documentoIdentificativo'])) {
			throw new Exception('El parametro documentoIdentificativo es obligatorio');
		}
		if (isset($vData['documentoIdentificativo'])) {
			$newClass = DocumentoIdentificativoType::fromSoap($vData['documentoIdentificativo']);
			$newItem->setDocumentoIdentificativo($newClass);
		}
		if (isset($vData['nombreApellidos'])) {
			$newItem->setNombreApellidos($vData['nombreApellidos']);
		}
		if (isset($vData['nombre'])) {
			$newItem->setNombre($vData['nombre']);
		}
		if (isset($vData['apellido1'])) {
			$newItem->setApellido1($vData['apellido1']);
		}
		if (isset($vData['apellido2'])) {
			$newItem->setApellido2($vData['apellido2']);
		}
		if (isset($vData['domicilio'])) {
			$newClass = DatosDomicilioType::fromSoap($vData['domicilio']);
			$newItem->setDomicilio($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_documentoIdentificativo, 'documentoIdentificativo', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_nombreApellidos, 'nombreApellidos', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_nombre, 'nombre', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_apellido1, 'apellido1', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_apellido2, 'apellido2', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_domicilio, 'domicilio', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DestinoType extends SoapObject {
	// name="organismoDestino" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_organismoDestino = null;
	private $_hasOrganismoDestino = false;
	public function setOrganismoDestino($value) {
		$this->_organismoDestino = $value;
		$this->_hasOrganismoDestino = ($value !== null);
	}
	public function hasOrganismoDestino() {
		return $this->_hasOrganismoDestino;
	}
	public function getOrganismoDestino() {
		return $this->_organismoDestino;
	}

	// name="unidadDestino" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_unidadDestino = null;
	private $_hasUnidadDestino = false;
	public function setUnidadDestino($value) {
		$this->_unidadDestino = $value;
		$this->_hasUnidadDestino = ($value !== null);
	}
	public function hasUnidadDestino() {
		return $this->_hasUnidadDestino;
	}
	public function getUnidadDestino() {
		return $this->_unidadDestino;
	}


	static public function fromSoap($vData) {
		$newItem = new DestinoType();
		if (!isset($vData['organismoDestino'])) {
			throw new Exception('El parametro organismoDestino es obligatorio');
		}
		if (isset($vData['organismoDestino'])) {
			$newItem->setOrganismoDestino($vData['organismoDestino']);
		}
		if (!isset($vData['unidadDestino'])) {
			throw new Exception('El parametro unidadDestino es obligatorio');
		}
		if (isset($vData['unidadDestino'])) {
			$newItem->setUnidadDestino($vData['unidadDestino']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_organismoDestino, 'organismoDestino', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_unidadDestino, 'unidadDestino', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DestinosType extends SoapObject {
	// name="destino" type="101"[101] minOccurs="1" maxOccurs="unbounded" nillable="false"
	private $_destino = array();
	private $_hasDestino = false;
	public function replaceArrayDestino($value) {
		$this->_destino = $value;
		$this->_hasDestino = (isset($this->_destino) && !empty($this->_destino));
	}
	public function retrieveArrayDestino() {
		return $this->_destino;
	}
	public function addDestino($value) {
		array_push($this->_destino, $value);
		$this->_hasDestino = (isset($this->_destino) && !empty($this->_destino));
	}
	public function hasDestino() {
		return $this->_hasDestino;
	}
	public function getDestino($index) {
		return $this->_destino[$index];
	}
	public function countDestino() {
		return count($this->_destino);
	}


	static public function fromSoap($vData) {
		$newItem = new DestinosType();
		if (!isset($vData['destino'])) {
			throw new Exception('El parametro destino es obligatorio');
		}
		if (is_array($vData['destino'])) {
			if (isset($vData['destino']) && !empty($vData['destino'])) {
				if (SoapObject::is_assoc($vData['destino'])) {
					// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
					$newItem->addDestino($vData['destino']);
				} else {
					$newItem->replaceAllDestino($vData['destino']);
				}
			}
		} else {
			$newItem->addDestino($vData['destino']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_destino, 'destino', 101, $namespace, 1, unbounded);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosRegistroType extends SoapObject {
	// name="organismo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_organismo = null;
	private $_hasOrganismo = false;
	public function setOrganismo($value) {
		$this->_organismo = $value;
		$this->_hasOrganismo = ($value !== null);
	}
	public function hasOrganismo() {
		return $this->_hasOrganismo;
	}
	public function getOrganismo() {
		return $this->_organismo;
	}

	// name="unidadRegistral" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_unidadRegistral = null;
	private $_hasUnidadRegistral = false;
	public function setUnidadRegistral($value) {
		$this->_unidadRegistral = $value;
		$this->_hasUnidadRegistral = ($value !== null);
	}
	public function hasUnidadRegistral() {
		return $this->_hasUnidadRegistral;
	}
	public function getUnidadRegistral() {
		return $this->_unidadRegistral;
	}

	// name="anyo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_anyo = null;
	private $_hasAnyo = false;
	public function setAnyo($value) {
		$this->_anyo = $value;
		$this->_hasAnyo = ($value !== null);
	}
	public function hasAnyo() {
		return $this->_hasAnyo;
	}
	public function getAnyo() {
		return $this->_anyo;
	}

	// name="numeroRegistro" type="131"[131] minOccurs="1" maxOccurs="1" nillable="false"
	private $_numeroRegistro = null;
	private $_hasNumeroRegistro = false;
	public function setNumeroRegistro($value) {
		$this->_numeroRegistro = $value;
		$this->_hasNumeroRegistro = ($value !== null);
	}
	public function hasNumeroRegistro() {
		return $this->_hasNumeroRegistro;
	}
	public function getNumeroRegistro() {
		return $this->_numeroRegistro;
	}


	static public function fromSoap($vData) {
		$newItem = new DatosRegistroType();
		if (!isset($vData['organismo'])) {
			throw new Exception('El parametro organismo es obligatorio');
		}
		if (isset($vData['organismo'])) {
			$newItem->setOrganismo($vData['organismo']);
		}
		if (!isset($vData['unidadRegistral'])) {
			throw new Exception('El parametro unidadRegistral es obligatorio');
		}
		if (isset($vData['unidadRegistral'])) {
			$newItem->setUnidadRegistral($vData['unidadRegistral']);
		}
		if (!isset($vData['anyo'])) {
			throw new Exception('El parametro anyo es obligatorio');
		}
		if (isset($vData['anyo'])) {
			$newItem->setAnyo($vData['anyo']);
		}
		if (!isset($vData['numeroRegistro'])) {
			throw new Exception('El parametro numeroRegistro es obligatorio');
		}
		if (isset($vData['numeroRegistro'])) {
			$newItem->setNumeroRegistro($vData['numeroRegistro']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_organismo, 'organismo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_unidadRegistral, 'unidadRegistral', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_anyo, 'anyo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_numeroRegistro, 'numeroRegistro', 131, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class IdentificacionRegistroDepartamentalType extends SoapObject {
	// name="organismo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_organismo = null;
	private $_hasOrganismo = false;
	public function setOrganismo($value) {
		$this->_organismo = $value;
		$this->_hasOrganismo = ($value !== null);
	}
	public function hasOrganismo() {
		return $this->_hasOrganismo;
	}
	public function getOrganismo() {
		return $this->_organismo;
	}

	// name="codigoUnidadDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoUnidadDepartamental = null;
	private $_hasCodigoUnidadDepartamental = false;
	public function setCodigoUnidadDepartamental($value) {
		$this->_codigoUnidadDepartamental = $value;
		$this->_hasCodigoUnidadDepartamental = ($value !== null);
	}
	public function hasCodigoUnidadDepartamental() {
		return $this->_hasCodigoUnidadDepartamental;
	}
	public function getCodigoUnidadDepartamental() {
		return $this->_codigoUnidadDepartamental;
	}

	// name="anyo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_anyo = null;
	private $_hasAnyo = false;
	public function setAnyo($value) {
		$this->_anyo = $value;
		$this->_hasAnyo = ($value !== null);
	}
	public function hasAnyo() {
		return $this->_hasAnyo;
	}
	public function getAnyo() {
		return $this->_anyo;
	}

	// name="numeroRegistro" type="131"[131] minOccurs="1" maxOccurs="1" nillable="false"
	private $_numeroRegistro = null;
	private $_hasNumeroRegistro = false;
	public function setNumeroRegistro($value) {
		$this->_numeroRegistro = $value;
		$this->_hasNumeroRegistro = ($value !== null);
	}
	public function hasNumeroRegistro() {
		return $this->_hasNumeroRegistro;
	}
	public function getNumeroRegistro() {
		return $this->_numeroRegistro;
	}

	// name="tipoRegistroDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_tipoRegistroDepartamental = null;
	private $_hasTipoRegistroDepartamental = false;
	public function setTipoRegistroDepartamental($value) {
		$this->_tipoRegistroDepartamental = $value;
		$this->_hasTipoRegistroDepartamental = ($value !== null);
	}
	public function hasTipoRegistroDepartamental() {
		return $this->_hasTipoRegistroDepartamental;
	}
	public function getTipoRegistroDepartamental() {
		return $this->_tipoRegistroDepartamental;
	}


	static public function fromSoap($vData) {
		$newItem = new IdentificacionRegistroDepartamentalType();
		if (!isset($vData['organismo'])) {
			throw new Exception('El parametro organismo es obligatorio');
		}
		if (isset($vData['organismo'])) {
			$newItem->setOrganismo($vData['organismo']);
		}
		if (!isset($vData['codigoUnidadDepartamental'])) {
			throw new Exception('El parametro codigoUnidadDepartamental es obligatorio');
		}
		if (isset($vData['codigoUnidadDepartamental'])) {
			$newItem->setCodigoUnidadDepartamental($vData['codigoUnidadDepartamental']);
		}
		if (!isset($vData['anyo'])) {
			throw new Exception('El parametro anyo es obligatorio');
		}
		if (isset($vData['anyo'])) {
			$newItem->setAnyo($vData['anyo']);
		}
		if (!isset($vData['numeroRegistro'])) {
			throw new Exception('El parametro numeroRegistro es obligatorio');
		}
		if (isset($vData['numeroRegistro'])) {
			$newItem->setNumeroRegistro($vData['numeroRegistro']);
		}
		if (!isset($vData['tipoRegistroDepartamental'])) {
			throw new Exception('El parametro tipoRegistroDepartamental es obligatorio');
		}
		if (isset($vData['tipoRegistroDepartamental'])) {
			$newItem->setTipoRegistroDepartamental($vData['tipoRegistroDepartamental']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_organismo, 'organismo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoUnidadDepartamental, 'codigoUnidadDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_anyo, 'anyo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_numeroRegistro, 'numeroRegistro', 131, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_tipoRegistroDepartamental, 'tipoRegistroDepartamental', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosExpedienteType extends SoapObject {
	// name="maquina" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_maquina = null;
	private $_hasMaquina = false;
	public function setMaquina($value) {
		$this->_maquina = $value;
		$this->_hasMaquina = ($value !== null);
	}
	public function hasMaquina() {
		return $this->_hasMaquina;
	}
	public function getMaquina() {
		return $this->_maquina;
	}

	// name="numeroReset" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_numeroReset = null;
	private $_hasNumeroReset = false;
	public function setNumeroReset($value) {
		$this->_numeroReset = $value;
		$this->_hasNumeroReset = ($value !== null);
	}
	public function hasNumeroReset() {
		return $this->_hasNumeroReset;
	}
	public function getNumeroReset() {
		return $this->_numeroReset;
	}

	// name="codigoExpediente" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoExpediente = null;
	private $_hasCodigoExpediente = false;
	public function setCodigoExpediente($value) {
		$this->_codigoExpediente = $value;
		$this->_hasCodigoExpediente = ($value !== null);
	}
	public function hasCodigoExpediente() {
		return $this->_hasCodigoExpediente;
	}
	public function getCodigoExpediente() {
		return $this->_codigoExpediente;
	}


	static public function fromSoap($vData) {
		$newItem = new DatosExpedienteType();
		if (isset($vData['maquina'])) {
			$newItem->setMaquina($vData['maquina']);
		}
		if (isset($vData['numeroReset'])) {
			$newItem->setNumeroReset($vData['numeroReset']);
		}
		if (isset($vData['codigoExpediente'])) {
			$newItem->setCodigoExpediente($vData['codigoExpediente']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_maquina, 'maquina', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_numeroReset, 'numeroReset', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_codigoExpediente, 'codigoExpediente', 101, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DocumentoType extends SoapObject {
	// name="codigoNormalizadoDocumento" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoNormalizadoDocumento = null;
	private $_hasCodigoNormalizadoDocumento = false;
	public function setCodigoNormalizadoDocumento($value) {
		$this->_codigoNormalizadoDocumento = $value;
		$this->_hasCodigoNormalizadoDocumento = ($value !== null);
	}
	public function hasCodigoNormalizadoDocumento() {
		return $this->_hasCodigoNormalizadoDocumento;
	}
	public function getCodigoNormalizadoDocumento() {
		return $this->_codigoNormalizadoDocumento;
	}

	// name="descripcionDocumento" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_descripcionDocumento = null;
	private $_hasDescripcionDocumento = false;
	public function setDescripcionDocumento($value) {
		$this->_descripcionDocumento = $value;
		$this->_hasDescripcionDocumento = ($value !== null);
	}
	public function hasDescripcionDocumento() {
		return $this->_hasDescripcionDocumento;
	}
	public function getDescripcionDocumento() {
		return $this->_descripcionDocumento;
	}

	// name="nombreDocumento" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_nombreDocumento = null;
	private $_hasNombreDocumento = false;
	public function setNombreDocumento($value) {
		$this->_nombreDocumento = $value;
		$this->_hasNombreDocumento = ($value !== null);
	}
	public function hasNombreDocumento() {
		return $this->_hasNombreDocumento;
	}
	public function getNombreDocumento() {
		return $this->_nombreDocumento;
	}

	// name="fechaDocumento" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_fechaDocumento = null;
	private $_hasFechaDocumento = false;
	public function setFechaDocumento($value) {
		$this->_fechaDocumento = $value;
		$this->_hasFechaDocumento = ($value !== null);
	}
	public function hasFechaDocumento() {
		return $this->_hasFechaDocumento;
	}
	public function getFechaDocumento() {
		return $this->_fechaDocumento;
	}

	// name="contenido" type="116"[116] minOccurs="1" maxOccurs="1" nillable="false"
	private $_contenido = null;
	private $_hasContenido = false;
	public function setContenido($value) {
		$this->_contenido = $value;
		$this->_hasContenido = ($value !== null);
	}
	public function hasContenido() {
		return $this->_hasContenido;
	}
	public function getContenido() {
		return $this->_contenido;
	}

	// name="hash" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_hash = null;
	private $_hasHash = false;
	public function setHash($value) {
		$this->_hash = $value;
		$this->_hasHash = ($value !== null);
	}
	public function hasHash() {
		return $this->_hasHash;
	}
	public function getHash() {
		return $this->_hash;
	}


	static public function fromSoap($vData) {
		$newItem = new DocumentoType();
		if (isset($vData['codigoNormalizadoDocumento'])) {
			$newItem->setCodigoNormalizadoDocumento($vData['codigoNormalizadoDocumento']);
		}
		if (!isset($vData['descripcionDocumento'])) {
			throw new Exception('El parametro descripcionDocumento es obligatorio');
		}
		if (isset($vData['descripcionDocumento'])) {
			$newItem->setDescripcionDocumento($vData['descripcionDocumento']);
		}
		if (!isset($vData['nombreDocumento'])) {
			throw new Exception('El parametro nombreDocumento es obligatorio');
		}
		if (isset($vData['nombreDocumento'])) {
			$newItem->setNombreDocumento($vData['nombreDocumento']);
		}
		if (!isset($vData['fechaDocumento'])) {
			throw new Exception('El parametro fechaDocumento es obligatorio');
		}
		if (isset($vData['fechaDocumento'])) {
			$newItem->setFechaDocumento($vData['fechaDocumento']);
		}
		if (!isset($vData['contenido'])) {
			throw new Exception('El parametro contenido es obligatorio');
		}
		if (isset($vData['contenido'])) {
			$newItem->setContenido($vData['contenido']);
		}
		if (!isset($vData['hash'])) {
			throw new Exception('El parametro hash es obligatorio');
		}
		if (isset($vData['hash'])) {
			$newItem->setHash($vData['hash']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoNormalizadoDocumento, 'codigoNormalizadoDocumento', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_descripcionDocumento, 'descripcionDocumento', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_nombreDocumento, 'nombreDocumento', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fechaDocumento, 'fechaDocumento', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_contenido, 'contenido', 116, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_hash, 'hash', 101, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DocumentosType extends SoapObject {
	// name="documento" type="tns:DocumentoType"[COMPLEXTYPE] minOccurs="1" maxOccurs="unbounded" nillable="false"
	private $_documento = array();
	private $_hasDocumento = false;
	public function replaceArrayDocumento($value) {
		$this->_documento = $value;
		$this->_hasDocumento = (isset($this->_documento) && !empty($this->_documento));
	}
	public function retrieveArrayDocumento() {
		return $this->_documento;
	}
	public function addDocumento($value) {
		array_push($this->_documento, $value);
		$this->_hasDocumento = (isset($this->_documento) && !empty($this->_documento));
	}
	public function hasDocumento() {
		return $this->_hasDocumento;
	}
	public function getDocumento($index) {
		return $this->_documento[$index];
	}
	public function countDocumento() {
		return count($this->_documento);
	}


	static public function fromSoap($vData) {
		$newItem = new DocumentosType();
		if (!isset($vData['documento'])) {
			throw new Exception('El parametro documento es obligatorio');
		}
		if (isset($vData['documento']) && !empty($vData['documento'])) {
			if (SoapObject::is_assoc($vData['documento'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DocumentoType::fromSoap($vData['documento']);
				$newItem->addDocumento($newClass);
			} else {
				foreach ($vData['documento'] as $oVar) {
					$newClass = DocumentoType::fromSoap($oVar);
					$newItem->addDocumento($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_documento, 'documento', SOAP_ENC_OBJECT, $namespace, 1, unbounded);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosRegistroDepartamentalType extends SoapObject {
	// name="codigoOrganismoUnidadDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoOrganismoUnidadDepartamental = null;
	private $_hasCodigoOrganismoUnidadDepartamental = false;
	public function setCodigoOrganismoUnidadDepartamental($value) {
		$this->_codigoOrganismoUnidadDepartamental = $value;
		$this->_hasCodigoOrganismoUnidadDepartamental = ($value !== null);
	}
	public function hasCodigoOrganismoUnidadDepartamental() {
		return $this->_hasCodigoOrganismoUnidadDepartamental;
	}
	public function getCodigoOrganismoUnidadDepartamental() {
		return $this->_codigoOrganismoUnidadDepartamental;
	}

	// name="codigoUnidadDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoUnidadDepartamental = null;
	private $_hasCodigoUnidadDepartamental = false;
	public function setCodigoUnidadDepartamental($value) {
		$this->_codigoUnidadDepartamental = $value;
		$this->_hasCodigoUnidadDepartamental = ($value !== null);
	}
	public function hasCodigoUnidadDepartamental() {
		return $this->_hasCodigoUnidadDepartamental;
	}
	public function getCodigoUnidadDepartamental() {
		return $this->_codigoUnidadDepartamental;
	}

	// name="anyo" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_anyo = null;
	private $_hasAnyo = false;
	public function setAnyo($value) {
		$this->_anyo = $value;
		$this->_hasAnyo = ($value !== null);
	}
	public function hasAnyo() {
		return $this->_hasAnyo;
	}
	public function getAnyo() {
		return $this->_anyo;
	}

	// name="numeroRegistro" type="131"[131] minOccurs="1" maxOccurs="1" nillable="false"
	private $_numeroRegistro = null;
	private $_hasNumeroRegistro = false;
	public function setNumeroRegistro($value) {
		$this->_numeroRegistro = $value;
		$this->_hasNumeroRegistro = ($value !== null);
	}
	public function hasNumeroRegistro() {
		return $this->_hasNumeroRegistro;
	}
	public function getNumeroRegistro() {
		return $this->_numeroRegistro;
	}

	// name="fechaRegistro" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fechaRegistro = null;
	private $_hasFechaRegistro = false;
	public function setFechaRegistro($value) {
		$this->_fechaRegistro = $value;
		$this->_hasFechaRegistro = ($value !== null);
	}
	public function hasFechaRegistro() {
		return $this->_hasFechaRegistro;
	}
	public function getFechaRegistro() {
		return $this->_fechaRegistro;
	}

	// name="anulado" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_anulado = null;
	private $_hasAnulado = false;
	public function setAnulado($value) {
		$this->_anulado = $value;
		$this->_hasAnulado = ($value !== null);
	}
	public function hasAnulado() {
		return $this->_hasAnulado;
	}
	public function getAnulado() {
		return $this->_anulado;
	}

	// name="estado" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_estado = null;
	private $_hasEstado = false;
	public function setEstado($value) {
		$this->_estado = $value;
		$this->_hasEstado = ($value !== null);
	}
	public function hasEstado() {
		return $this->_hasEstado;
	}
	public function getEstado() {
		return $this->_estado;
	}

	// name="motivoRechazo" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_motivoRechazo = null;
	private $_hasMotivoRechazo = false;
	public function setMotivoRechazo($value) {
		$this->_motivoRechazo = $value;
		$this->_hasMotivoRechazo = ($value !== null);
	}
	public function hasMotivoRechazo() {
		return $this->_hasMotivoRechazo;
	}
	public function getMotivoRechazo() {
		return $this->_motivoRechazo;
	}

	// name="tipoRegistroDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_tipoRegistroDepartamental = null;
	private $_hasTipoRegistroDepartamental = false;
	public function setTipoRegistroDepartamental($value) {
		$this->_tipoRegistroDepartamental = $value;
		$this->_hasTipoRegistroDepartamental = ($value !== null);
	}
	public function hasTipoRegistroDepartamental() {
		return $this->_hasTipoRegistroDepartamental;
	}
	public function getTipoRegistroDepartamental() {
		return $this->_tipoRegistroDepartamental;
	}

	// name="codigoAsuntoHabitual" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoAsuntoHabitual = null;
	private $_hasCodigoAsuntoHabitual = false;
	public function setCodigoAsuntoHabitual($value) {
		$this->_codigoAsuntoHabitual = $value;
		$this->_hasCodigoAsuntoHabitual = ($value !== null);
	}
	public function hasCodigoAsuntoHabitual() {
		return $this->_hasCodigoAsuntoHabitual;
	}
	public function getCodigoAsuntoHabitual() {
		return $this->_codigoAsuntoHabitual;
	}

	// name="asunto" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_asunto = null;
	private $_hasAsunto = false;
	public function setAsunto($value) {
		$this->_asunto = $value;
		$this->_hasAsunto = ($value !== null);
	}
	public function hasAsunto() {
		return $this->_hasAsunto;
	}
	public function getAsunto() {
		return $this->_asunto;
	}

	// name="observacionesDepartamentales" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_observacionesDepartamentales = null;
	private $_hasObservacionesDepartamentales = false;
	public function setObservacionesDepartamentales($value) {
		$this->_observacionesDepartamentales = $value;
		$this->_hasObservacionesDepartamentales = ($value !== null);
	}
	public function hasObservacionesDepartamentales() {
		return $this->_hasObservacionesDepartamentales;
	}
	public function getObservacionesDepartamentales() {
		return $this->_observacionesDepartamentales;
	}

	// name="observacionesGenerales" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_observacionesGenerales = null;
	private $_hasObservacionesGenerales = false;
	public function setObservacionesGenerales($value) {
		$this->_observacionesGenerales = $value;
		$this->_hasObservacionesGenerales = ($value !== null);
	}
	public function hasObservacionesGenerales() {
		return $this->_hasObservacionesGenerales;
	}
	public function getObservacionesGenerales() {
		return $this->_observacionesGenerales;
	}

	// name="datosIdentificativos" type="tns:DatosIdentificativosType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_datosIdentificativos = null;
	private $_hasDatosIdentificativos = false;
	public function setDatosIdentificativos($value) {
		$this->_datosIdentificativos = $value;
		$this->_hasDatosIdentificativos = ($value !== null);
	}
	public function hasDatosIdentificativos() {
		return $this->_hasDatosIdentificativos;
	}
	public function getDatosIdentificativos() {
		return $this->_datosIdentificativos;
	}

	// name="destinos" type="tns:DestinosType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_destinos = null;
	private $_hasDestinos = false;
	public function setDestinos($value) {
		$this->_destinos = $value;
		$this->_hasDestinos = ($value !== null);
	}
	public function hasDestinos() {
		return $this->_hasDestinos;
	}
	public function getDestinos() {
		return $this->_destinos;
	}

	// name="datosRegistroDepartamentalAsociado" type="tns:IdentificacionRegistroDepartamentalType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroDepartamentalAsociado = null;
	private $_hasDatosRegistroDepartamentalAsociado = false;
	public function setDatosRegistroDepartamentalAsociado($value) {
		$this->_datosRegistroDepartamentalAsociado = $value;
		$this->_hasDatosRegistroDepartamentalAsociado = ($value !== null);
	}
	public function hasDatosRegistroDepartamentalAsociado() {
		return $this->_hasDatosRegistroDepartamentalAsociado;
	}
	public function getDatosRegistroDepartamentalAsociado() {
		return $this->_datosRegistroDepartamentalAsociado;
	}

	// name="datosRegistroGeneralEntrada" type="tns:DatosRegistroType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroGeneralEntrada = null;
	private $_hasDatosRegistroGeneralEntrada = false;
	public function setDatosRegistroGeneralEntrada($value) {
		$this->_datosRegistroGeneralEntrada = $value;
		$this->_hasDatosRegistroGeneralEntrada = ($value !== null);
	}
	public function hasDatosRegistroGeneralEntrada() {
		return $this->_hasDatosRegistroGeneralEntrada;
	}
	public function getDatosRegistroGeneralEntrada() {
		return $this->_datosRegistroGeneralEntrada;
	}

	// name="datosRegistroGeneralSalida" type="tns:DatosRegistroType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroGeneralSalida = null;
	private $_hasDatosRegistroGeneralSalida = false;
	public function setDatosRegistroGeneralSalida($value) {
		$this->_datosRegistroGeneralSalida = $value;
		$this->_hasDatosRegistroGeneralSalida = ($value !== null);
	}
	public function hasDatosRegistroGeneralSalida() {
		return $this->_hasDatosRegistroGeneralSalida;
	}
	public function getDatosRegistroGeneralSalida() {
		return $this->_datosRegistroGeneralSalida;
	}

	// name="otraUnidadDeProcedencia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_otraUnidadDeProcedencia = null;
	private $_hasOtraUnidadDeProcedencia = false;
	public function setOtraUnidadDeProcedencia($value) {
		$this->_otraUnidadDeProcedencia = $value;
		$this->_hasOtraUnidadDeProcedencia = ($value !== null);
	}
	public function hasOtraUnidadDeProcedencia() {
		return $this->_hasOtraUnidadDeProcedencia;
	}
	public function getOtraUnidadDeProcedencia() {
		return $this->_otraUnidadDeProcedencia;
	}

	// name="descripcionOtraUnidadDeProcedencia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_descripcionOtraUnidadDeProcedencia = null;
	private $_hasDescripcionOtraUnidadDeProcedencia = false;
	public function setDescripcionOtraUnidadDeProcedencia($value) {
		$this->_descripcionOtraUnidadDeProcedencia = $value;
		$this->_hasDescripcionOtraUnidadDeProcedencia = ($value !== null);
	}
	public function hasDescripcionOtraUnidadDeProcedencia() {
		return $this->_hasDescripcionOtraUnidadDeProcedencia;
	}
	public function getDescripcionOtraUnidadDeProcedencia() {
		return $this->_descripcionOtraUnidadDeProcedencia;
	}

	// name="datosRegistroDepartamentalOrigen" type="tns:IdentificacionRegistroDepartamentalType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroDepartamentalOrigen = null;
	private $_hasDatosRegistroDepartamentalOrigen = false;
	public function setDatosRegistroDepartamentalOrigen($value) {
		$this->_datosRegistroDepartamentalOrigen = $value;
		$this->_hasDatosRegistroDepartamentalOrigen = ($value !== null);
	}
	public function hasDatosRegistroDepartamentalOrigen() {
		return $this->_hasDatosRegistroDepartamentalOrigen;
	}
	public function getDatosRegistroDepartamentalOrigen() {
		return $this->_datosRegistroDepartamentalOrigen;
	}

	// name="tipoTransporte" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_tipoTransporte = null;
	private $_hasTipoTransporte = false;
	public function setTipoTransporte($value) {
		$this->_tipoTransporte = $value;
		$this->_hasTipoTransporte = ($value !== null);
	}
	public function hasTipoTransporte() {
		return $this->_hasTipoTransporte;
	}
	public function getTipoTransporte() {
		return $this->_tipoTransporte;
	}

	// name="datosExpediente" type="tns:DatosExpedienteType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosExpediente = null;
	private $_hasDatosExpediente = false;
	public function setDatosExpediente($value) {
		$this->_datosExpediente = $value;
		$this->_hasDatosExpediente = ($value !== null);
	}
	public function hasDatosExpediente() {
		return $this->_hasDatosExpediente;
	}
	public function getDatosExpediente() {
		return $this->_datosExpediente;
	}

	// name="documentos" type="tns:DocumentosType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_documentos = null;
	private $_hasDocumentos = false;
	public function setDocumentos($value) {
		$this->_documentos = $value;
		$this->_hasDocumentos = ($value !== null);
	}
	public function hasDocumentos() {
		return $this->_hasDocumentos;
	}
	public function getDocumentos() {
		return $this->_documentos;
	}


	static public function fromSoap($vData) {
		$newItem = new DatosRegistroDepartamentalType();
		if (!isset($vData['codigoOrganismoUnidadDepartamental'])) {
			throw new Exception('El parametro codigoOrganismoUnidadDepartamental es obligatorio');
		}
		if (isset($vData['codigoOrganismoUnidadDepartamental'])) {
			$newItem->setCodigoOrganismoUnidadDepartamental($vData['codigoOrganismoUnidadDepartamental']);
		}
		if (!isset($vData['codigoUnidadDepartamental'])) {
			throw new Exception('El parametro codigoUnidadDepartamental es obligatorio');
		}
		if (isset($vData['codigoUnidadDepartamental'])) {
			$newItem->setCodigoUnidadDepartamental($vData['codigoUnidadDepartamental']);
		}
		if (!isset($vData['anyo'])) {
			throw new Exception('El parametro anyo es obligatorio');
		}
		if (isset($vData['anyo'])) {
			$newItem->setAnyo($vData['anyo']);
		}
		if (!isset($vData['numeroRegistro'])) {
			throw new Exception('El parametro numeroRegistro es obligatorio');
		}
		if (isset($vData['numeroRegistro'])) {
			$newItem->setNumeroRegistro($vData['numeroRegistro']);
		}
		if (isset($vData['fechaRegistro'])) {
			$newItem->setFechaRegistro($vData['fechaRegistro']);
		}
		if (!isset($vData['anulado'])) {
			throw new Exception('El parametro anulado es obligatorio');
		}
		if (isset($vData['anulado'])) {
			$newItem->setAnulado($vData['anulado']);
		}
		if (!isset($vData['estado'])) {
			throw new Exception('El parametro estado es obligatorio');
		}
		if (isset($vData['estado'])) {
			$newItem->setEstado($vData['estado']);
		}
		if (isset($vData['motivoRechazo'])) {
			$newItem->setMotivoRechazo($vData['motivoRechazo']);
		}
		if (!isset($vData['tipoRegistroDepartamental'])) {
			throw new Exception('El parametro tipoRegistroDepartamental es obligatorio');
		}
		if (isset($vData['tipoRegistroDepartamental'])) {
			$newItem->setTipoRegistroDepartamental($vData['tipoRegistroDepartamental']);
		}
		if (isset($vData['codigoAsuntoHabitual'])) {
			$newItem->setCodigoAsuntoHabitual($vData['codigoAsuntoHabitual']);
		}
		if (!isset($vData['asunto'])) {
			throw new Exception('El parametro asunto es obligatorio');
		}
		if (isset($vData['asunto'])) {
			$newItem->setAsunto($vData['asunto']);
		}
		if (isset($vData['observacionesDepartamentales'])) {
			$newItem->setObservacionesDepartamentales($vData['observacionesDepartamentales']);
		}
		if (isset($vData['observacionesGenerales'])) {
			$newItem->setObservacionesGenerales($vData['observacionesGenerales']);
		}
		if (!isset($vData['datosIdentificativos'])) {
			throw new Exception('El parametro datosIdentificativos es obligatorio');
		}
		if (isset($vData['datosIdentificativos'])) {
			$newClass = DatosIdentificativosType::fromSoap($vData['datosIdentificativos']);
			$newItem->setDatosIdentificativos($newClass);
		}
		if (isset($vData['destinos'])) {
			$newClass = DestinosType::fromSoap($vData['destinos']);
			$newItem->setDestinos($newClass);
		}
		if (isset($vData['datosRegistroDepartamentalAsociado'])) {
			$newClass = IdentificacionRegistroDepartamentalType::fromSoap($vData['datosRegistroDepartamentalAsociado']);
			$newItem->setDatosRegistroDepartamentalAsociado($newClass);
		}
		if (isset($vData['datosRegistroGeneralEntrada'])) {
			$newClass = DatosRegistroType::fromSoap($vData['datosRegistroGeneralEntrada']);
			$newItem->setDatosRegistroGeneralEntrada($newClass);
		}
		if (isset($vData['datosRegistroGeneralSalida'])) {
			$newClass = DatosRegistroType::fromSoap($vData['datosRegistroGeneralSalida']);
			$newItem->setDatosRegistroGeneralSalida($newClass);
		}
		if (isset($vData['otraUnidadDeProcedencia'])) {
			$newItem->setOtraUnidadDeProcedencia($vData['otraUnidadDeProcedencia']);
		}
		if (isset($vData['descripcionOtraUnidadDeProcedencia'])) {
			$newItem->setDescripcionOtraUnidadDeProcedencia($vData['descripcionOtraUnidadDeProcedencia']);
		}
		if (isset($vData['datosRegistroDepartamentalOrigen'])) {
			$newClass = IdentificacionRegistroDepartamentalType::fromSoap($vData['datosRegistroDepartamentalOrigen']);
			$newItem->setDatosRegistroDepartamentalOrigen($newClass);
		}
		if (isset($vData['tipoTransporte'])) {
			$newItem->setTipoTransporte($vData['tipoTransporte']);
		}
		if (isset($vData['datosExpediente'])) {
			$newClass = DatosExpedienteType::fromSoap($vData['datosExpediente']);
			$newItem->setDatosExpediente($newClass);
		}
		if (isset($vData['documentos'])) {
			$newClass = DocumentosType::fromSoap($vData['documentos']);
			$newItem->setDocumentos($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoOrganismoUnidadDepartamental, 'codigoOrganismoUnidadDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoUnidadDepartamental, 'codigoUnidadDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_anyo, 'anyo', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_numeroRegistro, 'numeroRegistro', 131, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fechaRegistro, 'fechaRegistro', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_anulado, 'anulado', 102, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_estado, 'estado', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_motivoRechazo, 'motivoRechazo', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_tipoRegistroDepartamental, 'tipoRegistroDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoAsuntoHabitual, 'codigoAsuntoHabitual', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_asunto, 'asunto', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_observacionesDepartamentales, 'observacionesDepartamentales', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_observacionesGenerales, 'observacionesGenerales', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosIdentificativos, 'datosIdentificativos', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_destinos, 'destinos', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroDepartamentalAsociado, 'datosRegistroDepartamentalAsociado', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroGeneralEntrada, 'datosRegistroGeneralEntrada', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroGeneralSalida, 'datosRegistroGeneralSalida', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_otraUnidadDeProcedencia, 'otraUnidadDeProcedencia', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_descripcionOtraUnidadDeProcedencia, 'descripcionOtraUnidadDeProcedencia', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroDepartamentalOrigen, 'datosRegistroDepartamentalOrigen', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_tipoTransporte, 'tipoTransporte', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosExpediente, 'datosExpediente', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_documentos, 'documentos', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class creacionRegistroDepartamental extends SoapObject {
	// name="codigoOrganismoUnidadDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoOrganismoUnidadDepartamental = null;
	private $_hasCodigoOrganismoUnidadDepartamental = false;
	public function setCodigoOrganismoUnidadDepartamental($value) {
		$this->_codigoOrganismoUnidadDepartamental = $value;
		$this->_hasCodigoOrganismoUnidadDepartamental = ($value !== null);
	}
	public function hasCodigoOrganismoUnidadDepartamental() {
		return $this->_hasCodigoOrganismoUnidadDepartamental;
	}
	public function getCodigoOrganismoUnidadDepartamental() {
		return $this->_codigoOrganismoUnidadDepartamental;
	}

	// name="codigoUnidadDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoUnidadDepartamental = null;
	private $_hasCodigoUnidadDepartamental = false;
	public function setCodigoUnidadDepartamental($value) {
		$this->_codigoUnidadDepartamental = $value;
		$this->_hasCodigoUnidadDepartamental = ($value !== null);
	}
	public function hasCodigoUnidadDepartamental() {
		return $this->_hasCodigoUnidadDepartamental;
	}
	public function getCodigoUnidadDepartamental() {
		return $this->_codigoUnidadDepartamental;
	}

	// name="tipoRegistroDepartamental" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_tipoRegistroDepartamental = null;
	private $_hasTipoRegistroDepartamental = false;
	public function setTipoRegistroDepartamental($value) {
		$this->_tipoRegistroDepartamental = $value;
		$this->_hasTipoRegistroDepartamental = ($value !== null);
	}
	public function hasTipoRegistroDepartamental() {
		return $this->_hasTipoRegistroDepartamental;
	}
	public function getTipoRegistroDepartamental() {
		return $this->_tipoRegistroDepartamental;
	}

	// name="codigoAsuntoHabitual" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoAsuntoHabitual = null;
	private $_hasCodigoAsuntoHabitual = false;
	public function setCodigoAsuntoHabitual($value) {
		$this->_codigoAsuntoHabitual = $value;
		$this->_hasCodigoAsuntoHabitual = ($value !== null);
	}
	public function hasCodigoAsuntoHabitual() {
		return $this->_hasCodigoAsuntoHabitual;
	}
	public function getCodigoAsuntoHabitual() {
		return $this->_codigoAsuntoHabitual;
	}

	// name="asunto" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_asunto = null;
	private $_hasAsunto = false;
	public function setAsunto($value) {
		$this->_asunto = $value;
		$this->_hasAsunto = ($value !== null);
	}
	public function hasAsunto() {
		return $this->_hasAsunto;
	}
	public function getAsunto() {
		return $this->_asunto;
	}

	// name="observacionesDepartamentales" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_observacionesDepartamentales = null;
	private $_hasObservacionesDepartamentales = false;
	public function setObservacionesDepartamentales($value) {
		$this->_observacionesDepartamentales = $value;
		$this->_hasObservacionesDepartamentales = ($value !== null);
	}
	public function hasObservacionesDepartamentales() {
		return $this->_hasObservacionesDepartamentales;
	}
	public function getObservacionesDepartamentales() {
		return $this->_observacionesDepartamentales;
	}

	// name="observacionesGenerales" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_observacionesGenerales = null;
	private $_hasObservacionesGenerales = false;
	public function setObservacionesGenerales($value) {
		$this->_observacionesGenerales = $value;
		$this->_hasObservacionesGenerales = ($value !== null);
	}
	public function hasObservacionesGenerales() {
		return $this->_hasObservacionesGenerales;
	}
	public function getObservacionesGenerales() {
		return $this->_observacionesGenerales;
	}

	// name="datosIdentificativos" type="tns:DatosIdentificativosType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_datosIdentificativos = null;
	private $_hasDatosIdentificativos = false;
	public function setDatosIdentificativos($value) {
		$this->_datosIdentificativos = $value;
		$this->_hasDatosIdentificativos = ($value !== null);
	}
	public function hasDatosIdentificativos() {
		return $this->_hasDatosIdentificativos;
	}
	public function getDatosIdentificativos() {
		return $this->_datosIdentificativos;
	}

	// name="destinos" type="tns:DestinosType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_destinos = null;
	private $_hasDestinos = false;
	public function setDestinos($value) {
		$this->_destinos = $value;
		$this->_hasDestinos = ($value !== null);
	}
	public function hasDestinos() {
		return $this->_hasDestinos;
	}
	public function getDestinos() {
		return $this->_destinos;
	}

	// name="datosRegistroGeneralSalida" type="tns:DatosRegistroType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroGeneralSalida = null;
	private $_hasDatosRegistroGeneralSalida = false;
	public function setDatosRegistroGeneralSalida($value) {
		$this->_datosRegistroGeneralSalida = $value;
		$this->_hasDatosRegistroGeneralSalida = ($value !== null);
	}
	public function hasDatosRegistroGeneralSalida() {
		return $this->_hasDatosRegistroGeneralSalida;
	}
	public function getDatosRegistroGeneralSalida() {
		return $this->_datosRegistroGeneralSalida;
	}

	// name="otraUnidadDeProcedencia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_otraUnidadDeProcedencia = null;
	private $_hasOtraUnidadDeProcedencia = false;
	public function setOtraUnidadDeProcedencia($value) {
		$this->_otraUnidadDeProcedencia = $value;
		$this->_hasOtraUnidadDeProcedencia = ($value !== null);
	}
	public function hasOtraUnidadDeProcedencia() {
		return $this->_hasOtraUnidadDeProcedencia;
	}
	public function getOtraUnidadDeProcedencia() {
		return $this->_otraUnidadDeProcedencia;
	}

	// name="descripcionOtraUnidadDeProcedencia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_descripcionOtraUnidadDeProcedencia = null;
	private $_hasDescripcionOtraUnidadDeProcedencia = false;
	public function setDescripcionOtraUnidadDeProcedencia($value) {
		$this->_descripcionOtraUnidadDeProcedencia = $value;
		$this->_hasDescripcionOtraUnidadDeProcedencia = ($value !== null);
	}
	public function hasDescripcionOtraUnidadDeProcedencia() {
		return $this->_hasDescripcionOtraUnidadDeProcedencia;
	}
	public function getDescripcionOtraUnidadDeProcedencia() {
		return $this->_descripcionOtraUnidadDeProcedencia;
	}

	// name="datosRegistroDepartamentalOrigen" type="tns:IdentificacionRegistroDepartamentalType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroDepartamentalOrigen = null;
	private $_hasDatosRegistroDepartamentalOrigen = false;
	public function setDatosRegistroDepartamentalOrigen($value) {
		$this->_datosRegistroDepartamentalOrigen = $value;
		$this->_hasDatosRegistroDepartamentalOrigen = ($value !== null);
	}
	public function hasDatosRegistroDepartamentalOrigen() {
		return $this->_hasDatosRegistroDepartamentalOrigen;
	}
	public function getDatosRegistroDepartamentalOrigen() {
		return $this->_datosRegistroDepartamentalOrigen;
	}

	// name="tipoTransporte" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_tipoTransporte = null;
	private $_hasTipoTransporte = false;
	public function setTipoTransporte($value) {
		$this->_tipoTransporte = $value;
		$this->_hasTipoTransporte = ($value !== null);
	}
	public function hasTipoTransporte() {
		return $this->_hasTipoTransporte;
	}
	public function getTipoTransporte() {
		return $this->_tipoTransporte;
	}

	// name="datosExpediente" type="tns:DatosExpedienteType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosExpediente = null;
	private $_hasDatosExpediente = false;
	public function setDatosExpediente($value) {
		$this->_datosExpediente = $value;
		$this->_hasDatosExpediente = ($value !== null);
	}
	public function hasDatosExpediente() {
		return $this->_hasDatosExpediente;
	}
	public function getDatosExpediente() {
		return $this->_datosExpediente;
	}

	// name="documentos" type="tns:DocumentosType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_documentos = null;
	private $_hasDocumentos = false;
	public function setDocumentos($value) {
		$this->_documentos = $value;
		$this->_hasDocumentos = ($value !== null);
	}
	public function hasDocumentos() {
		return $this->_hasDocumentos;
	}
	public function getDocumentos() {
		return $this->_documentos;
	}


	static public function fromSoap($vData) {
		$newItem = new creacionRegistroDepartamental();
		if (!isset($vData['codigoOrganismoUnidadDepartamental'])) {
			throw new Exception('El parametro codigoOrganismoUnidadDepartamental es obligatorio');
		}
		if (isset($vData['codigoOrganismoUnidadDepartamental'])) {
			$newItem->setCodigoOrganismoUnidadDepartamental($vData['codigoOrganismoUnidadDepartamental']);
		}
		if (!isset($vData['codigoUnidadDepartamental'])) {
			throw new Exception('El parametro codigoUnidadDepartamental es obligatorio');
		}
		if (isset($vData['codigoUnidadDepartamental'])) {
			$newItem->setCodigoUnidadDepartamental($vData['codigoUnidadDepartamental']);
		}
		if (!isset($vData['tipoRegistroDepartamental'])) {
			throw new Exception('El parametro tipoRegistroDepartamental es obligatorio');
		}
		if (isset($vData['tipoRegistroDepartamental'])) {
			$newItem->setTipoRegistroDepartamental($vData['tipoRegistroDepartamental']);
		}
		if (isset($vData['codigoAsuntoHabitual'])) {
			$newItem->setCodigoAsuntoHabitual($vData['codigoAsuntoHabitual']);
		}
		if (!isset($vData['asunto'])) {
			throw new Exception('El parametro asunto es obligatorio');
		}
		if (isset($vData['asunto'])) {
			$newItem->setAsunto($vData['asunto']);
		}
		if (isset($vData['observacionesDepartamentales'])) {
			$newItem->setObservacionesDepartamentales($vData['observacionesDepartamentales']);
		}
		if (isset($vData['observacionesGenerales'])) {
			$newItem->setObservacionesGenerales($vData['observacionesGenerales']);
		}
		if (!isset($vData['datosIdentificativos'])) {
			throw new Exception('El parametro datosIdentificativos es obligatorio');
		}
		if (isset($vData['datosIdentificativos'])) {
			$newClass = DatosIdentificativosType::fromSoap($vData['datosIdentificativos']);
			$newItem->setDatosIdentificativos($newClass);
		}
		if (isset($vData['destinos'])) {
			$newClass = DestinosType::fromSoap($vData['destinos']);
			$newItem->setDestinos($newClass);
		}
		if (isset($vData['datosRegistroGeneralSalida'])) {
			$newClass = DatosRegistroType::fromSoap($vData['datosRegistroGeneralSalida']);
			$newItem->setDatosRegistroGeneralSalida($newClass);
		}
		if (isset($vData['otraUnidadDeProcedencia'])) {
			$newItem->setOtraUnidadDeProcedencia($vData['otraUnidadDeProcedencia']);
		}
		if (isset($vData['descripcionOtraUnidadDeProcedencia'])) {
			$newItem->setDescripcionOtraUnidadDeProcedencia($vData['descripcionOtraUnidadDeProcedencia']);
		}
		if (isset($vData['datosRegistroDepartamentalOrigen'])) {
			$newClass = IdentificacionRegistroDepartamentalType::fromSoap($vData['datosRegistroDepartamentalOrigen']);
			$newItem->setDatosRegistroDepartamentalOrigen($newClass);
		}
		if (isset($vData['tipoTransporte'])) {
			$newItem->setTipoTransporte($vData['tipoTransporte']);
		}
		if (isset($vData['datosExpediente'])) {
			$newClass = DatosExpedienteType::fromSoap($vData['datosExpediente']);
			$newItem->setDatosExpediente($newClass);
		}
		if (isset($vData['documentos'])) {
			$newClass = DocumentosType::fromSoap($vData['documentos']);
			$newItem->setDocumentos($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoOrganismoUnidadDepartamental, 'codigoOrganismoUnidadDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoUnidadDepartamental, 'codigoUnidadDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_tipoRegistroDepartamental, 'tipoRegistroDepartamental', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoAsuntoHabitual, 'codigoAsuntoHabitual', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_asunto, 'asunto', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_observacionesDepartamentales, 'observacionesDepartamentales', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_observacionesGenerales, 'observacionesGenerales', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosIdentificativos, 'datosIdentificativos', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_destinos, 'destinos', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroGeneralSalida, 'datosRegistroGeneralSalida', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_otraUnidadDeProcedencia, 'otraUnidadDeProcedencia', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_descripcionOtraUnidadDeProcedencia, 'descripcionOtraUnidadDeProcedencia', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosRegistroDepartamentalOrigen, 'datosRegistroDepartamentalOrigen', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_tipoTransporte, 'tipoTransporte', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_datosExpediente, 'datosExpediente', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_documentos, 'documentos', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class creacionRegistroDepartamentalResponse extends SoapObject {
	// name="resultado" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_resultado = null;
	private $_hasResultado = false;
	public function setResultado($value) {
		$this->_resultado = $value;
		$this->_hasResultado = ($value !== null);
	}
	public function hasResultado() {
		return $this->_hasResultado;
	}
	public function getResultado() {
		return $this->_resultado;
	}

	// name="registrosCreados" type="tns:RegistrosCreadosType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_registrosCreados = null;
	private $_hasRegistrosCreados = false;
	public function setRegistrosCreados($value) {
		$this->_registrosCreados = $value;
		$this->_hasRegistrosCreados = ($value !== null);
	}
	public function hasRegistrosCreados() {
		return $this->_hasRegistrosCreados;
	}
	public function getRegistrosCreados() {
		return $this->_registrosCreados;
	}

	// name="error" type="tns:ErrorInfoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_error = null;
	private $_hasError = false;
	public function setError($value) {
		$this->_error = $value;
		$this->_hasError = ($value !== null);
	}
	public function hasError() {
		return $this->_hasError;
	}
	public function getError() {
		return $this->_error;
	}


	static public function fromSoap($vData) {
		$newItem = new creacionRegistroDepartamentalResponse();
		if (!isset($vData['resultado'])) {
			throw new Exception('El parametro resultado es obligatorio');
		}
		if (isset($vData['resultado'])) {
			$newItem->setResultado($vData['resultado']);
		}
		if (isset($vData['registrosCreados'])) {
			$newClass = RegistrosCreadosType::fromSoap($vData['registrosCreados']);
			$newItem->setRegistrosCreados($newClass);
		}
		if (isset($vData['error'])) {
			$newClass = ErrorInfoType::fromSoap($vData['error']);
			$newItem->setError($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_resultado, 'resultado', 102, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_registrosCreados, 'registrosCreados', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_error, 'error', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class consultaRegistroDepartamental extends SoapObject {
	// name="codigoRegistroDepartamental" type="tns:RegistroDepartamentalCodigoType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoRegistroDepartamental = null;
	private $_hasCodigoRegistroDepartamental = false;
	public function setCodigoRegistroDepartamental($value) {
		$this->_codigoRegistroDepartamental = $value;
		$this->_hasCodigoRegistroDepartamental = ($value !== null);
	}
	public function hasCodigoRegistroDepartamental() {
		return $this->_hasCodigoRegistroDepartamental;
	}
	public function getCodigoRegistroDepartamental() {
		return $this->_codigoRegistroDepartamental;
	}

	// name="devolverDocumentos" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_devolverDocumentos = null;
	private $_hasDevolverDocumentos = false;
	public function setDevolverDocumentos($value) {
		$this->_devolverDocumentos = $value;
		$this->_hasDevolverDocumentos = ($value !== null);
	}
	public function hasDevolverDocumentos() {
		return $this->_hasDevolverDocumentos;
	}
	public function getDevolverDocumentos() {
		return $this->_devolverDocumentos;
	}


	static public function fromSoap($vData) {
		$newItem = new consultaRegistroDepartamental();
		if (!isset($vData['codigoRegistroDepartamental'])) {
			throw new Exception('El parametro codigoRegistroDepartamental es obligatorio');
		}
		if (isset($vData['codigoRegistroDepartamental'])) {
			$newClass = RegistroDepartamentalCodigoType::fromSoap($vData['codigoRegistroDepartamental']);
			$newItem->setCodigoRegistroDepartamental($newClass);
		}
		if (!isset($vData['devolverDocumentos'])) {
			throw new Exception('El parametro devolverDocumentos es obligatorio');
		}
		if (isset($vData['devolverDocumentos'])) {
			$newItem->setDevolverDocumentos($vData['devolverDocumentos']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoRegistroDepartamental, 'codigoRegistroDepartamental', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_devolverDocumentos, 'devolverDocumentos', 102, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class consultaRegistroDepartamentalResponse extends SoapObject {
	// name="resultado" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_resultado = null;
	private $_hasResultado = false;
	public function setResultado($value) {
		$this->_resultado = $value;
		$this->_hasResultado = ($value !== null);
	}
	public function hasResultado() {
		return $this->_hasResultado;
	}
	public function getResultado() {
		return $this->_resultado;
	}

	// name="datosRegistroDepartamental" type="tns:DatosRegistroDepartamentalType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_datosRegistroDepartamental = null;
	private $_hasDatosRegistroDepartamental = false;
	public function setDatosRegistroDepartamental($value) {
		$this->_datosRegistroDepartamental = $value;
		$this->_hasDatosRegistroDepartamental = ($value !== null);
	}
	public function hasDatosRegistroDepartamental() {
		return $this->_hasDatosRegistroDepartamental;
	}
	public function getDatosRegistroDepartamental() {
		return $this->_datosRegistroDepartamental;
	}

	// name="error" type="tns:ErrorInfoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_error = null;
	private $_hasError = false;
	public function setError($value) {
		$this->_error = $value;
		$this->_hasError = ($value !== null);
	}
	public function hasError() {
		return $this->_hasError;
	}
	public function getError() {
		return $this->_error;
	}


	static public function fromSoap($vData) {
		$newItem = new consultaRegistroDepartamentalResponse();
		if (!isset($vData['resultado'])) {
			throw new Exception('El parametro resultado es obligatorio');
		}
		if (isset($vData['resultado'])) {
			$newItem->setResultado($vData['resultado']);
		}
		if (isset($vData['datosRegistroDepartamental'])) {
			$newClass = DatosRegistroDepartamentalType::fromSoap($vData['datosRegistroDepartamental']);
			$newItem->setDatosRegistroDepartamental($newClass);
		}
		if (isset($vData['error'])) {
			$newClass = ErrorInfoType::fromSoap($vData['error']);
			$newItem->setError($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_resultado, 'resultado', 102, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_datosRegistroDepartamental, 'datosRegistroDepartamental', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_error, 'error', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class consultaHistorico extends SoapObject {
	// name="codigoRegistroDepartamental" type="tns:RegistroDepartamentalCodigoType"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_codigoRegistroDepartamental = null;
	private $_hasCodigoRegistroDepartamental = false;
	public function setCodigoRegistroDepartamental($value) {
		$this->_codigoRegistroDepartamental = $value;
		$this->_hasCodigoRegistroDepartamental = ($value !== null);
	}
	public function hasCodigoRegistroDepartamental() {
		return $this->_hasCodigoRegistroDepartamental;
	}
	public function getCodigoRegistroDepartamental() {
		return $this->_codigoRegistroDepartamental;
	}


	static public function fromSoap($vData) {
		$newItem = new consultaHistorico();
		if (!isset($vData['codigoRegistroDepartamental'])) {
			throw new Exception('El parametro codigoRegistroDepartamental es obligatorio');
		}
		if (isset($vData['codigoRegistroDepartamental'])) {
			$newClass = RegistroDepartamentalCodigoType::fromSoap($vData['codigoRegistroDepartamental']);
			$newItem->setCodigoRegistroDepartamental($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codigoRegistroDepartamental, 'codigoRegistroDepartamental', SOAP_ENC_OBJECT, $namespace, 1, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class consultaHistoricoResponse extends SoapObject {
	// name="resultado" type="102"[102] minOccurs="1" maxOccurs="1" nillable="false"
	private $_resultado = null;
	private $_hasResultado = false;
	public function setResultado($value) {
		$this->_resultado = $value;
		$this->_hasResultado = ($value !== null);
	}
	public function hasResultado() {
		return $this->_hasResultado;
	}
	public function getResultado() {
		return $this->_resultado;
	}

	// name="codigoRegistroDepartamentalConsulta" type="tns:RegistroDepartamentalCodigoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_codigoRegistroDepartamentalConsulta = null;
	private $_hasCodigoRegistroDepartamentalConsulta = false;
	public function setCodigoRegistroDepartamentalConsulta($value) {
		$this->_codigoRegistroDepartamentalConsulta = $value;
		$this->_hasCodigoRegistroDepartamentalConsulta = ($value !== null);
	}
	public function hasCodigoRegistroDepartamentalConsulta() {
		return $this->_hasCodigoRegistroDepartamentalConsulta;
	}
	public function getCodigoRegistroDepartamentalConsulta() {
		return $this->_codigoRegistroDepartamentalConsulta;
	}

	// name="historico" type="tns:HistoricoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_historico = null;
	private $_hasHistorico = false;
	public function setHistorico($value) {
		$this->_historico = $value;
		$this->_hasHistorico = ($value !== null);
	}
	public function hasHistorico() {
		return $this->_hasHistorico;
	}
	public function getHistorico() {
		return $this->_historico;
	}

	// name="error" type="tns:ErrorInfoType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_error = null;
	private $_hasError = false;
	public function setError($value) {
		$this->_error = $value;
		$this->_hasError = ($value !== null);
	}
	public function hasError() {
		return $this->_hasError;
	}
	public function getError() {
		return $this->_error;
	}


	static public function fromSoap($vData) {
		$newItem = new consultaHistoricoResponse();
		if (!isset($vData['resultado'])) {
			throw new Exception('El parametro resultado es obligatorio');
		}
		if (isset($vData['resultado'])) {
			$newItem->setResultado($vData['resultado']);
		}
		if (isset($vData['codigoRegistroDepartamentalConsulta'])) {
			$newClass = RegistroDepartamentalCodigoType::fromSoap($vData['codigoRegistroDepartamentalConsulta']);
			$newItem->setCodigoRegistroDepartamentalConsulta($newClass);
		}
		if (isset($vData['historico'])) {
			$newClass = HistoricoType::fromSoap($vData['historico']);
			$newItem->setHistorico($newClass);
		}
		if (isset($vData['error'])) {
			$newClass = ErrorInfoType::fromSoap($vData['error']);
			$newItem->setError($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_resultado, 'resultado', 102, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_codigoRegistroDepartamentalConsulta, 'codigoRegistroDepartamentalConsulta', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_historico, 'historico', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_error, 'error', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

?>